# FlightplanDB-py

## Code status
![Unittests and lint](https://github.com/PH-KDX/flightplandb-py/actions/workflows/test_and_lint.yml/badge.svg)

## Introduction
This is a Python 3 wrapper for the [Flight Plan Database API](https://flightplandatabase.com/dev/api). Flight Plan Database is a website for creating and sharing flight plans for use in flight simulation.

For more information on Flight Plan Database, see their excellent [About page](https://flightplandatabase.com/about).


## API
All the API commands can be called via the `flightplandb.FlightPlanDB` class.
It is organized into subsections as specified in the docs; i.e. `FlightPlanDB.plan` has all the plan API commands.

## Data Types
All datatypes can be found in `flightplandb.datatypes`.

## Exceptions
All exceptions can be found in `flightplandb.exceptions`.

## Documentation
The documentation for this project can be found on readthedocs.io [here](https://flightplandb-py.readthedocs.io/).
